@@ -1,3 +1,13 @@
+###################################################
+#### independent copula class
+###################################################
+setClass("indepCopula",
+         representation(dimension = "numeric",
+                        message = "character"),
+         contains = list()
+         )
+
+
 ###################################################
 ##### basic copula class
 ###################################################
